==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-ro_RO-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ro_RO\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  "Utilizator"
 ,"Utilizatori"
 ,"Utilizatori"

]
, "Groups"
: "Grupuri"

, "Roles"
: "Roluri"

, "Applications"
: "Aplicaţii"

, "Containers"
: "Containere"

, "Shared Tags"
: ""

, "Customfields"
: ""

, "Computers"
: "Calculatoare"

, "Access Log, Access Logs"
: [
  ""
 ,""
 ,""

]
, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "Admin"
: "Admin"

, "Refresh"
: ""

, "Name"
: "Nume"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  "Calculator"
 ,"Calculatoare"
 ,"Calculatoare"

]
, "Default Addressbook for new contacts and groups"
: ""

, "Group, Groups"
: [
  "Grup"
 ,"Grupuri"
 ,"Grupuri"

]
, "Application, Applications"
: [
  "Aplicaţie"
 ,"Aplicaţii"
 ,"Aplicaţii"

]
, "Config, Configs"
: [
  ""
 ,""
 ,""

]
, "Configs"
: ""

, "Please wait"
: ""

, "Updating Memberships"
: ""

, "Failed"
: ""

, "Could not save group."
: ""

, "Errors"
: "Erori"

, "Please fix the errors noted."
: ""

, "Group Name"
: "Nume Grup"

, "Description"
: "Descriere"

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "Group Members"
: ""

, "Transferring {0}..."
: ""

, "Add new group"
: ""

, "Edit Group \"{0}\""
: ""

, "Enable Application"
: "Activare Aplicaţie"

, "Disable Application"
: "Dezctivare Aplicaţie"

, "Settings"
: "Setări"

, "{0} Settings"
: "{0} Setări"

, "enable application"
: "activare aplicaţie"

, "disable application"
: "dezactivare aplicaţie"

, "settings"
: ""

, "Search:"
: ""

, "disabled"
: ""

, "enabled"
: ""

, "unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: ""

, "No applications to display"
: ""

, "Order"
: ""

, "Status"
: "Status"

, "Version"
: "Versiune"

, "Confirm"
: "Confirm"

, "Do you really want to delete the selected groups?"
: ""

, "Deleting group(s)..."
: ""

, "Some error occurred while trying to delete the group."
: ""

, "Add Group"
: "Adaugă Grup"

, "Edit Group"
: "Editează Grup"

, "Delete Group"
: "Şterge Grup"

, "Displaying groups {0} - {1} of {2}"
: ""

, "No groups to display"
: ""

, "ID"
: "ID"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: ""

, "IP Address"
: ""

, "Login Time"
: ""

, "Logout Time"
: ""

, "Client Type"
: "Tip Client "

, "Session ID"
: "ID Sesiune"

, "Login Name"
: "Nume Login"

, "Result"
: "Resultat"

, "user blocked"
: "utilizator blocat"

, "password expired"
: "parolă expirată"

, "user disabled"
: "utilizator dezactivat"

, "invalid password"
: "parolă invalidă"

, "ambiguous username"
: "nume utilizator ambigu"

, "user not found"
: "utilizator negăsit"

, "failure"
: "eşec"

, "success"
: "succes"

, "Could not save role."
: ""

, "Deleting role..."
: ""

, "Some error occurred while trying to delete the role."
: ""

, "Rights"
: ""

, "Members"
: "Membri"

, "Role Name"
: "Nume Rol"

, "Role"
: "Rol"

, "Add New Role"
: "Adaugă Rol Nou"

, "Edit Role \"{0}\""
: ""

, "Container Name"
: ""

, "Type"
: "Tip"

, "Container Order"
: ""

, "Container, Containers"
: [
  ""
 ,""
 ,""

]
, "Model"
: "Model"

, "personal"
: "personal"

, "shared"
: ""

, "Color"
: "Culoare"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Do you really want to delete the selected roles?"
: ""

, "Deleting role(s)..."
: ""

, "Add Role"
: "Adaugă Rol"

, "Edit Role"
: "Editează Rol"

, "Delete Role"
: "Şterge Rol"

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: ""

, "Do you really want to delete the selected tags?"
: ""

, "Deleting tag(s)..."
: ""

, "Add Tag"
: "Adaugă Tag"

, "Edit Tag"
: "Editează Tag"

, "Delete Tag"
: "Şterge  Tag"

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: ""

, "Usage:&#160;"
: ""

, "Label"
: "Etichetă"

, "Value"
: "Valoare"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  ""
 ,""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: ""

, "Record Class"
: "Clasă înregistrată"

, "Given record class not found"
: ""

, "Cancel"
: "Anulează"

, "OK"
: "OK"

, "Configure store"
: ""

, "Custom field definition"
: ""

, "Text"
: "Text"

, "Textarea"
: ""

, "Number"
: "Număr"

, "Date"
: "Date"

, "DateTime"
: "DateTimp"

, "Time"
: "Timp"

, "Boolean"
: "Boolean"

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Length"
: "Lungime"

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: "Activează Cont"

, "Disable Account"
: "Dezactivează Cont"

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: "Nume afişat"

, "Login name"
: ""

, "Last name"
: "Nume"

, "First name"
: "Prenume"

, "Email"
: "Email"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: ""

, "Last login from"
: ""

, "Password changed"
: ""

, "Expires"
: ""

, "Set new password"
: ""

, "Please enter the new password:"
: ""

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: "Utilizatori"

, "Samba User, Samba Users"
: [
  ""
 ,""
 ,""

]
, "Email User, Email Users"
: [
  ""
 ,""
 ,""

]
, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: "Parolele corespund!"

, "Primary group"
: ""

, "Unix"
: "Unix"

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: "Windows"

, "Home Drive"
: ""

, "Logon Time"
: ""

, "never logged in"
: ""

, "Home Path"
: ""

, "Logoff Time"
: ""

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: ""

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Password Must Change"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "Informare"

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: ""

, "Add an alias address..."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: ""

, "Email Forward"
: ""

, "Add a forward address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: "Confirmare parolă"

, "Repeat password"
: "Repetă parola"

, "Ok"
: "Ok"

, "Account"
: "Cont"

, "Password"
: "Parola"

, "expired"
: "expirat"

, "blocked"
: "blocat"

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: ""

, "Password set"
: ""

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: ""

, "Context"
: ""

, "Account Rights"
: ""

, "View"
: ""

, "Use"
: ""

, "Tag Name"
: ""

, "Tag"
: "Tag"

, "Add New Tag"
: ""

, "Edit Tag \"{0}\""
: ""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: ""

, "delete access log entries"
: ""

, "manage accounts"
: ""

, "add and edit users and groups, add group members, change user passwords"
: ""

, "manage applications"
: ""

, "enable and disable applications, edit application settings"
: ""

, "manage roles"
: ""

, "add and edit roles, add new members to roles, add application rights to roles"
: ""

, "manage shared tags"
: ""

, "add, delete and edit shared tags"
: ""

, "manage computers"
: ""

, "add, delete and edit (samba) computers"
: ""

, "manage containers"
: ""

, "add, delete and edit containers and manage container grants"
: ""

, "manage customfields"
: ""

, "add and edit customfields"
: ""

, "view access log"
: "vezi  logurile de acces"

, "view access log list"
: "vezi lista  logurilor de acces"

, "view accounts"
: "vezi conturile"

, "view accounts list and details"
: "vezilista conturilor si detaliilor"

, "view applications"
: "vezi  aplicaţiile"

, "view applications list and details"
: ""

, "view roles"
: "vezi rolurile"

, "view roles list and details"
: ""

, "view computers"
: "vezi calculatoarele"

, "view computers list and details"
: ""

, "view containers"
: "vezi containerele"

, "view personal and shared containers"
: ""

, "view customfields"
: "vezi câmpurile custom"

, "view customfields list"
: "vezi lista câmpurilor custom"

, "view serverinfo"
: "vezi info server"

, "view serverinfo list"
: "vezi lista info server"

, "view quota usage"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Could not save tag without (view-)rights"
: ""

, "User"
: "Utilizator"

, "Access Log"
: ""

, "Computer"
: "Calculator"

, "Group"
: "Grup"

, "Application"
: "Aplicaţie"

, "Config"
: ""

, "Container"
: ""

, "Customfield"
: ""

, "Samba User"
: ""

, "Email User"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Admin/js/Admin-lang-ro_RO-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nLanguage: ro_RO\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: "Activare Aplicaţie"

, "Disable Application"
: "Dezctivare Aplicaţie"

, "Settings"
: "Setări"

, "{0} Settings"
: "{0} Setări"

, "Search:"
: ""

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: ""

, "No applications to display"
: ""

, "Order"
: ""

, "Name"
: "Nume"

, "Status"
: "Status"

, "Version"
: "Versiune"

, "Confirm"
: "Confirm"

, "Do you really want to delete the selected groups?"
: ""

, "Deleting group(s)..."
: ""

, "Failed"
: ""

, "Some error occurred while trying to delete the group."
: ""

, "Add Group"
: "Adaugă Grup"

, "Edit Group"
: "Editează Grup"

, "Delete Group"
: "Şterge Grup"

, "Displaying groups {0} - {1} of {2}"
: ""

, "No groups to display"
: ""

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "Descriere"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Erori"

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  "Aplicaţie"
 ,"Aplicaţii"
 ,"Aplicaţii"

]
, "Record Class"
: "Clasă înregistrată"

, "Given record class not found"
: ""

, "Cancel"
: "Anulează"

, "OK"
: "OK"

, "Configure store"
: ""

, "Model"
: "Model"

, "Custom field definition"
: ""

, "Text"
: "Text"

, "Textarea"
: ""

, "Number"
: "Număr"

, "Date"
: "Date"

, "DateTime"
: "DateTimp"

, "Time"
: "Timp"

, "Boolean"
: "Boolean"

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Type"
: "Tip"

, "Label"
: "Etichetă"

, "Length"
: "Lungime"

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Grup"
 ,"Grupuri"
 ,"Grupuri"

]
, "Customfield already exists. Please choose another name."
: ""

, "Customfield, Customfields"
: [
  ""
 ,""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""
 ,""

]
, "Value"
: "Valoare"

, "Default ({0})"
: ""

, "Computer Name"
: ""

, "Default Addressbook for new contacts and groups"
: ""

, "Please wait"
: ""

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: ""

, "Allowed Contexts"
: ""

, "Context"
: ""

, "Account Rights"
: ""

, "View"
: ""

, "Use"
: ""

, "Tag Name"
: ""

, "Color"
: "Culoare"

, "Transferring {0}..."
: ""

, "Tag"
: "Tag"

, "Add New Tag"
: ""

, "Edit Tag \"{0}\""
: ""

, "Do you really want to delete the selected tags?"
: ""

, "Deleting tag(s)..."
: ""

, "Add Tag"
: "Adaugă Tag"

, "Edit Tag"
: "Editează Tag"

, "Delete Tag"
: "Şterge  Tag"

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: ""

, "Usage:&#160;"
: ""

, "Updating Memberships"
: ""

, "Could not save role."
: ""

, "Deleting role..."
: ""

, "Some error occurred while trying to delete the role."
: ""

, "Rights"
: ""

, "Members"
: "Membri"

, "Role Name"
: "Nume Rol"

, "Role"
: "Rol"

, "Add New Role"
: "Adaugă Rol Nou"

, "Edit Role \"{0}\""
: ""

, "Do you really want to delete the selected roles?"
: ""

, "Deleting role(s)..."
: ""

, "Add Role"
: "Adaugă Rol"

, "Edit Role"
: "Editează Rol"

, "Delete Role"
: "Şterge Rol"

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: ""

, "Access Log, Access Logs"
: [
  ""
 ,""
 ,""

]
, "Groups"
: "Grupuri"

, "Applications"
: "Aplicaţii"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: "Parolele corespund!"

, "Primary group"
: ""

, "Unix"
: "Unix"

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: "Windows"

, "Home Drive"
: ""

, "Login Time"
: ""

, "never logged in"
: ""

, "Home Path"
: ""

, "Logout Time"
: ""

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: ""

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Password Must Change"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "Informare"

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: ""

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: "Confirmare parolă"

, "Repeat password"
: "Repetă parola"

, "Ok"
: "Ok"

, "Account"
: "Cont"

, "First name"
: "Prenume"

, "Last name"
: "Nume"

, "Login name"
: ""

, "Password"
: "Parola"

, "OpenID"
: "OpenID"

, "enabled"
: ""

, "disabled"
: ""

, "expired"
: "expirat"

, "blocked"
: "blocat"

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: ""

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "Last login at"
: ""

, "don't know"
: ""

, "Last login from"
: ""

, "Password set"
: ""

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  "Utilizator"
 ,"Utilizatori"
 ,"Utilizatori"

]
, "Users"
: "Utilizatori"

, "Samba User, Samba Users"
: [
  ""
 ,""
 ,""

]
, "Email User, Email Users"
: [
  ""
 ,""
 ,""

]
, "Enable Account"
: "Activează Cont"

, "Disable Account"
: "Dezactivează Cont"

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: "Nume afişat"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: ""

, "Set new password"
: ""

, "Please enter the new password:"
: ""

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Nume Grup"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: ""

, "personal"
: "personal"

, "shared"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  ""
 ,""
 ,""

]
, "Container Name"
: ""

, "Container Order"
: ""

, "Computer, Computers"
: [
  "Calculator"
 ,"Calculatoare"
 ,"Calculatoare"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Roluri"

, "Containers"
: "Containere"

, "Shared Tags"
: ""

, "Customfields"
: ""

, "Computers"
: "Calculatoare"

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Admin"

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: ""

, "Client Type"
: "Tip Client "

, "Session ID"
: "ID Sesiune"

, "Login Name"
: "Nume Login"

, "Result"
: "Resultat"

, "user blocked"
: "utilizator blocat"

, "password expired"
: "parolă expirată"

, "user disabled"
: "utilizator dezactivat"

, "invalid password"
: "parolă invalidă"

, "ambiguous username"
: "nume utilizator ambigu"

, "user not found"
: "utilizator negăsit"

, "failure"
: "eşec"

, "success"
: "succes"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""
















, "Application"
: "Aplicaţie"

, "Group"
: "Grup"

, "Customfield"
: ""

, "Config"
: ""

, "Access Log"
: ""

, "User"
: "Utilizator"

, "Samba User"
: ""

, "Email User"
: ""

, "Container"
: ""

, "Computer"
: "Calculator"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
